# `filesystemlib`

File-related utilities implemented in Python.

No install dependencies besides Python standard library.


## License

Copyright 2020 Christopher Brown.
[MIT Licensed](https://chbrown.github.io/licenses/MIT/#2020).
